@@ -6,6 +6,8 @@ class LeapDataType(Enum):
     Text = 'Text'
     Graph = 'Graph'
     Numeric = 'Numeric'
+    HorizontalBar = 'HorizontalBar'
+    Mask = 'Mask'
 
 
 class DatasetInputType(Enum):
