@@ -2,6 +2,7 @@ from typing import List, Optional, Dict
 
 from dataclasses import dataclass, field
 
+from code_loader.contract.datasetclasses import DecoderReturnType
 from code_loader.contract.enums import DatasetInputType, DatasetMetadataType, DatasetOutputType
 
 
@@ -20,7 +21,6 @@ class DatasetBaseSectionInstance:
 @dataclass
 class DatasetInputInstance(DatasetBaseSectionInstance):
     shape: List[int]
-    type: DatasetInputType
     decoder_name: str
 
 
@@ -32,16 +32,22 @@ class DatasetMetadataInstance(DatasetBaseSectionInstance):
 @dataclass
 class DatasetOutputInstance(DatasetBaseSectionInstance):
     shape: List[int]
-    type: DatasetOutputType
     decoder_name: str
 
 
+@dataclass
+class DecoderInstance:
+    name: str
+    type: DecoderReturnType
+
+
 @dataclass
 class DatasetSetup:
     preprocess: DatasetPreprocess
     inputs: List[DatasetInputInstance]
     metadata: List[DatasetMetadataInstance]
     outputs: List[DatasetOutputInstance]
+    decoders: List[DecoderInstance]
 
 
 @dataclass
