@@ -7,7 +7,8 @@ from code_loader.contract.datasetclasses import DatasetSample, DatasetBaseHandle
     GroundTruthHandler, PreprocessResponse, DecoderHandler, DecoderCallableReturnType
 from code_loader.contract.enums import DataStateEnum, TestingSectionEnum, DataStateType
 from code_loader.contract.responsedataclasses import DatasetIntegParseResult, DatasetTestResultPayload, \
-    DatasetPreprocess, DatasetSetup, DatasetInputInstance, DatasetOutputInstance, DatasetMetadataInstance
+    DatasetPreprocess, DatasetSetup, DatasetInputInstance, DatasetOutputInstance, DatasetMetadataInstance, \
+    DecoderInstance
 from code_loader.dataset_binder import global_dataset_binder
 from code_loader.utils import get_root_exception_line_number, get_shape
 
@@ -141,20 +142,24 @@ class DatasetLoader:
         inputs = []
         for inp in setup.inputs:
             if inp.shape is None:
-                raise Exception(f"cant calculate shape for input, input name:{inp.name}, input type:{inp.type}")
-            inputs.append(DatasetInputInstance(name=inp.name, shape=inp.shape, type=inp.type, decoder_name=inp.decoder_name))
+                raise Exception(f"cant calculate shape for input, input name:{inp.name}")
+            inputs.append(DatasetInputInstance(name=inp.name, shape=inp.shape, decoder_name=inp.decoder_name))
 
         ground_truths = []
         for gt in setup.ground_truths:
             if gt.shape is None:
-                raise Exception(f"cant calculate shape for ground truth, gt name:{gt.name}, gt type:{gt.type}")
+                raise Exception(f"cant calculate shape for ground truth, gt name:{gt.name}")
             ground_truths.append(
-                DatasetOutputInstance(name=gt.name, shape=gt.shape, type=gt.type, decoder_name=gt.decoder_name))
+                DatasetOutputInstance(name=gt.name, shape=gt.shape, decoder_name=gt.decoder_name))
 
         metadata = [DatasetMetadataInstance(name=metadata.name, type=metadata.type)
                     for metadata in setup.metadata]
 
-        return DatasetSetup(preprocess=dataset_preprocess, inputs=inputs, outputs=ground_truths, metadata=metadata)
+        decoders = [DecoderInstance(name=decoder_handler.name, type=decoder_handler.type)
+                    for decoder_handler in setup.decoders]
+
+        return DatasetSetup(preprocess=dataset_preprocess, inputs=inputs, outputs=ground_truths, metadata=metadata,
+                            decoders=decoders)
 
     @lru_cache()
     def _preprocess_result(self) -> List[PreprocessResponse]:
